==> haskell-filemanip-0.3.6.3-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filemanip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filemanip
version:              0.3.6.3
visibility:           public
id:                   filemanip-0.3.6.3-CwXgg7mM6wX3veTmRRP0Sh
key:                  filemanip-0.3.6.3-CwXgg7mM6wX3veTmRRP0Sh
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/filemanip
synopsis:             Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.

category:             System
abi:                  7965b2fea632ca46214a6cc5b2831965
exposed:              True
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filemanip
hs-libraries:         HSfilemanip-0.3.6.3-CwXgg7mM6wX3veTmRRP0Sh
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 unix-compat-0.7.3-9KJlYunG6iR1P9GL6FJB0c

haddock-interfaces:   /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html:         /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filemanip-0.3.6.3-187-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filemanip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filemanip
version:              0.3.6.3
visibility:           public
id:                   filemanip-0.3.6.3-6ZVRPFsl4j84Vydmo4g05Y
key:                  filemanip-0.3.6.3-6ZVRPFsl4j84Vydmo4g05Y
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/filemanip
synopsis:             Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.

category:             System
abi:                  39dc8f4e3e63c61a0ff1e11473485ed7
exposed:              True
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filemanip
hs-libraries:         HSfilemanip-0.3.6.3-6ZVRPFsl4j84Vydmo4g05Y
depends:
    base-4.17.2.1 bytestring-0.11.5.3 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 unix-compat-0.7.3-9Tj09IRjFnyE6cgV0AVkT

haddock-interfaces:   /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html:         /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
